summaryrefslogtreecommitdiff
path: root/test/buffer-diff.h
diff options
context:
space:
mode:
Diffstat (limited to 'test/buffer-diff.h')
-rw-r--r--test/buffer-diff.h15
1 files changed, 6 insertions, 9 deletions
diff --git a/test/buffer-diff.h b/test/buffer-diff.h
index d95c213b6..cd3534508 100644
--- a/test/buffer-diff.h
+++ b/test/buffer-diff.h
@@ -36,22 +36,19 @@ typedef struct _buffer_diff_result {
unsigned int max_diff;
} buffer_diff_result_t;
/* Compares two image buffers.
*
* Provides number of pixels changed and maximum single-channel
* difference in result.
*
* Also fills in a "diff" buffer intended to visually show where the
* images differ.
*/
void
-buffer_diff (unsigned char *buf_a,
- unsigned char *buf_b,
- unsigned char *buf_diff,
- int width,
- int height,
- int stride,
- buffer_diff_result_t *result);
+compare_surfaces (cairo_surface_t *surface_a,
+ cairo_surface_t *surface_b,
+ cairo_surface_t *surface_diff,
+ buffer_diff_result_t *result);
/* Compares two image buffers ignoring the alpha channel.
*
@@ -36,22 +36,19 @@ typedef struct _buffer_diff_result {
unsigned int max_diff;
} buffer_diff_result_t;
-/* Compares two image buffers.
+/* Compares two image surfaces
*
* Provides number of pixels changed and maximum single-channel
@@ -36,22 +36,19 @@ typedef struct _buffer_diff_result {
* difference in result.
*
- * Also fills in a "diff" buffer intended to visually show where the
+ * Also fills in a "diff" surface intended to visually show where the
* images differ.
*/